@@ -63,9 +63,16 @@ public:
      *  @returns A JSON-LD structure representing the boarding pass.
      */
     Q_INVOKABLE QVariant decodeIataBcbp(const QString &s) const;
+    /** Decode an VDV ticket barcode.
+     *  @param s A QByteArray containing the raw VDV barcode data.
+     *  @returns An instance of VdvTicket.
+     */
+    Q_INVOKABLE QVariant decodeVdvTicket(const QVariant &s) const;
 
     /** Converts the given QByteArray into an base64 encoded string. */
     Q_INVOKABLE QString toBase64(const QVariant &b) const;
+    /** Converts a given Base64 encoded string to a QByteArray. */
+    Q_INVOKABLE QVariant fromBase64(const QString &s) const;
     /** Converts the given QByteArray into a BitArray. */
     Q_INVOKABLE QVariant toBitArray(const QVariant &b) const;
 
