@@ -28,12 +28,6 @@ class QPainterPath;
 class QPen;
 class QTransform;
 
-#if KPOPPLER_VERSION >= QT_VERSION_CHECK(0, 83, 0)
-#define GFXPATH_CONST const
-#else
-#define GFXPATH_CONST
-#endif
-
 namespace KItinerary {
 
 /** Utilities for interacting with Poppler. */
@@ -47,7 +41,7 @@ namespace PopplerUtils
     QTransform currentTransform(GfxState *state);
 
     /** Convets a Poppler path into a Qt path. */
-    QPainterPath convertPath(GFXPATH_CONST GfxPath *path, Qt::FillRule fillRule);
+    QPainterPath convertPath(const GfxPath *path, Qt::FillRule fillRule);
 }
 
 }
